@@ -109,6 +109,7 @@ face_tool_button_reposition_window (GtkhtmlFaceToolButton *button)
 	GdkScreen *screen;
 	GdkWindow *window;
 	GdkRectangle monitor;
+	GtkAllocation allocation;
 	gint monitor_num;
 	gint x, y, width, height;
 
@@ -119,17 +120,15 @@ face_tool_button_reposition_window (GtkhtmlFaceToolButton *button)
 
 	gdk_window_get_origin (window, &x, &y);
 
-#if GTK_CHECK_VERSION(2,19,7)
 	if (!gtk_widget_get_has_window (GTK_WIDGET (button))) {
-#else
-	if (GTK_WIDGET_NO_WINDOW (button)) {
-#endif
-		x += GTK_WIDGET (button)->allocation.x;
-		y += GTK_WIDGET (button)->allocation.y;
+		gtk_widget_get_allocation (GTK_WIDGET (button), &allocation);
+		x += allocation.x;
+		y += allocation.y;
 	}
 
-	width = button->priv->window->allocation.width;
-	height = button->priv->window->allocation.height;
+	gtk_widget_get_allocation (button->priv->window, &allocation);
+	width = allocation.width;
+	height = allocation.height;
 
 	x = CLAMP (x, monitor.x, monitor.x + monitor.width - width);
 	y = CLAMP (y, monitor.y, monitor.y + monitor.height - height);
@@ -150,7 +149,11 @@ face_tool_button_face_release_event_cb (GtkhtmlFaceToolButton *button,
                                         GdkEventButton *event,
                                         GtkButton *face_button)
 {
-	if (GTK_WIDGET_STATE (button) != GTK_STATE_NORMAL)
+	GtkStateType state;
+
+	state = gtk_widget_get_state (GTK_WIDGET (button));
+
+	if (state != GTK_STATE_NORMAL)
 		gtk_button_clicked (face_button);
 
 	return FALSE;
@@ -207,8 +210,8 @@ face_tool_button_child_key_press_event_cb (GtkhtmlFaceToolButton *button,
 {
 	GtkWidget *window = button->priv->window;
 
-	if (!gtk_bindings_activate_event (GTK_OBJECT (window), event))
-		gtk_bindings_activate_event (GTK_OBJECT (button), event);
+	if (!gtk_bindings_activate_event (G_OBJECT (window), event))
+		gtk_bindings_activate_event (G_OBJECT (button), event);
 
 	return TRUE;
 }
@@ -328,11 +331,7 @@ face_tool_button_popup (GtkhtmlFaceToolButton *button)
 	GdkWindow *window;
 	GdkGrabStatus status;
 
-#if GTK_CHECK_VERSION(2,19,7)
 	if (!gtk_widget_get_realized (GTK_WIDGET (button)))
-#else
-	if (!GTK_WIDGET_REALIZED (button))
-#endif
 		return;
 
 	if (button->priv->popup_shown)
@@ -359,7 +358,7 @@ face_tool_button_popup (GtkhtmlFaceToolButton *button)
 		status = gdk_keyboard_grab (window, TRUE, GDK_CURRENT_TIME);
 		if (status != GDK_GRAB_SUCCESS)
 			gdk_display_pointer_ungrab (
-				gdk_drawable_get_display (window),
+				gdk_window_get_display (window),
 				GDK_CURRENT_TIME);
 	}
 
@@ -374,11 +373,7 @@ face_tool_button_popdown (GtkhtmlFaceToolButton *button)
 {
 	GtkToggleToolButton *tool_button;
 
-#if GTK_CHECK_VERSION(2,19,7)
 	if (!gtk_widget_get_realized (GTK_WIDGET (button)))
-#else
-	if (!GTK_WIDGET_REALIZED (button))
-#endif
 		return;
 
 	if (!button->priv->popup_shown)
@@ -491,20 +486,20 @@ face_tool_button_class_init (GtkhtmlFaceToolButtonClass *class)
 
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_Down, GDK_MOD1_MASK, "popup", 0);
+		GDK_KEY_Down, GDK_MOD1_MASK, "popup", 0);
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_KP_Down, GDK_MOD1_MASK, "popup", 0);
+		GDK_KEY_KP_Down, GDK_MOD1_MASK, "popup", 0);
 
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_Up, GDK_MOD1_MASK, "popdown", 0);
+		GDK_KEY_Up, GDK_MOD1_MASK, "popdown", 0);
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_KP_Up, GDK_MOD1_MASK, "popdown", 0);
+		GDK_KEY_KP_Up, GDK_MOD1_MASK, "popdown", 0);
 	gtk_binding_entry_add_signal (
 		gtk_binding_set_by_class (class),
-		GDK_Escape, 0, "popdown", 0);
+		GDK_KEY_Escape, 0, "popdown", 0);
 }
 
 static void
